@@ -1,9 +1,9 @@
 package App::FirefoxMultiAccountContainersUtils;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-05-26'; # DATE
+our $DATE = '2020-05-27'; # DATE
 our $DIST = 'App-FirefoxMultiAccountContainersUtils'; # DIST
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -66,7 +66,12 @@ sub firefox_mua_sort_containers {
     $res = App::FirefoxUtils::firefox_is_running();
     return [500, "Can't check if Firefox is running: $res->[0] - $res->[1]"]
         unless $res->[0] == 200;
-    return [412, "Please stop Firefox first"] if $res->[2];
+    if ($args{-dry_run}) {
+        log_info "[DRY-RUN] Note that Firefox is still running, ".
+            "you should stop Firefox first when actually sorting containers";
+    } else {
+        return [412, "Please stop Firefox first"] if $res->[2];
+    }
 
     $res = Firefox::Util::Profile::list_firefox_profiles(detail=>1);
     return [500, "Can't list Firefox profiles: $res->[0] - $res->[1]"]
@@ -129,7 +134,7 @@ App::FirefoxMultiAccountContainersUtils - Utilities related to Firefox Multi-Acc
 
 =head1 VERSION
 
-This document describes version 0.004 of App::FirefoxMultiAccountContainersUtils (from Perl distribution App-FirefoxMultiAccountContainersUtils), released on 2020-05-26.
+This document describes version 0.005 of App::FirefoxMultiAccountContainersUtils (from Perl distribution App-FirefoxMultiAccountContainersUtils), released on 2020-05-27.
 
 =head1 SYNOPSIS
 
